@@ -2,11 +2,7 @@
 import joblib
 from io import BytesIO
 import boto3
-
-
-
-
-
+from tsfresh.feature_extraction import settings, extract_features
 
 
 
@@ -52,11 +48,14 @@ def load_model(path):
 
 
 
+def get_prediction_features(df, relevant_features, id='exp_unique_id', timesteps='timesteps'):
 
-def get_prediction_features(df, fc_parameters, id='exp_unique_id', timesteps='timesteps'):
+    fc_parameters = settings.from_columns(relevant_features)
 
     prediction_data = extract_features(df, kind_to_fc_parameters =fc_parameters, column_id=id, column_sort=timesteps)
 
+    prediction_data.columns = prediction_data.columns.str.replace('["]', '')
+
     return prediction_data
 
 
