@@ -1,25 +1,18 @@
 # Importing the Packages:
 import optuna
-import pandas as pd
 import mlflow
 import os
 
-try:
-    from sklearn.utils import safe_indexing
-except ImportError:
-    from sklearn.utils import _safe_indexing
+# try:
+#     from sklearn.utils import safe_indexing
+# except ImportError:
+#     from sklearn.utils import _safe_indexing
 
     
 from pycaret.classification import *
-import numpy as np
-import pandas as pd
 from sklearn.metrics import recall_score
 from mlflow.models.signature import infer_signature
 
-from tsfresh.feature_extraction import settings
-import copy
-
-
 
 
 
@@ -38,21 +31,17 @@ REMOTE_TRACKING_URI = 'http://ec2-3-10-175-206.eu-west-2.compute.amazonaws.com:5
 
 
 
-# artifact_path = 's3://raptor-mlflow-data/mlartifacts/1/83318437749c4e59a4950f55a98b2ad6/artifacts'
-# artifact_path = 's3://raptor-mlflow-data'
-
-
 def get_plots(model):
 
     model_attributes = dir(model)
 
     plot_model(model, plot = 'confusion_matrix', save=True)
-    cm = os.path.join(os.getcwd(), 'Confusion Matrix.png')
+    cm = os.path.join(os.getcwd(), 'plots/Confusion Matrix.png')
     mlflow.log_artifact(cm)
     # log_artifact(cm)
 
     plot_model(model, plot = 'class_report', save=True) 
-    cr = os.path.join(os.getcwd(), 'Class Report.png')
+    cr = os.path.join(os.getcwd(), 'plots/Class Report.png')
     mlflow.log_artifact(cr)  
     # log_artifact(cr)
     
@@ -61,15 +50,15 @@ def get_plots(model):
     if 'predict_proba' in model_attributes:
         try:
             plot_model(model, plot = 'auc', save=True)
-            auc = os.path.join(os.getcwd(), 'AUC.png')
+            auc = os.path.join(os.getcwd(), 'plots/AUC.png')
             mlflow.log_artifact(auc) 
 
             plot_model(model, plot = 'pr', save=True) 
-            pr = os.path.join(os.getcwd(), 'Precision Recall.png')
+            pr = os.path.join(os.getcwd(), 'plots/Precision Recall.png')
             mlflow.log_artifact(pr)
 
             plot_model(model, plot = 'calibration', save=True) 
-            cc = os.path.join(os.getcwd(), 'Calibration Curve.png')
+            cc = os.path.join(os.getcwd(), 'plots/Calibration Curve.png')
             mlflow.log_artifact(cc)
         except:
             pass
@@ -78,7 +67,7 @@ def get_plots(model):
     
     if 'feature_importances_' in model_attributes:  
         plot_model(model, plot = 'feature', save=True)  
-        fi = os.path.join(os.getcwd(), 'Feature Importance.png')
+        fi = os.path.join(os.getcwd(), 'plots/Feature Importance.png')
         mlflow.log_artifact(fi)
 
 
@@ -208,13 +197,9 @@ def train_experiments(df, study_name='raptor', direction='maximize', model_mode=
     Args:
         df (pandas dataframe): dataframe of cyclic sensor data to be used for training
         study_name (str, optional): optuna study name to use. Defaults to 'raptor'.
-        direction (str, optional): dirtection of objective. Defaults to 'maximize'.
-        stage (str or list, optional): Can take any of ('baseline', 'absorb', 'pause', 'desorb', 'flush') as a str or combination as a list. 
-                                        Can also take str 'all' for all stages and 'random' for random stage or stages. Defaults to 'pause'.        sensor (str, optional): _description_. Defaults to '12'.
-        use_average (bool, optional): if True, uses average of stages selected. Defaults to False.
+        direction (str, optional): direction of objective. Defaults to 'maximize'.
         model_mode (str, optional): _description_. Defaults to 'random'.
         n_trials (int, optional): number of times to run experiments. Defaults to 5.
-        suggest (bool, optional): if True, suggest features, stage, model mode to use for training. Defaults to False.
     """    
     
     
